@@ -1,7 +1,10 @@
 // {% raw %}
-
+/**
+ * justpy event handler
+ */
 var files_chosen = {};
 
+
 function eventHandler(props, event, form_data, aux) {
 
     if (props.jp_props.debug) {
@@ -133,8 +136,7 @@ function send_to_server(e, event_type, debug_flag) {
     }
     if (use_websockets) {
         if (web_socket_closed) {
-            let ok_to_reload = confirm('Page needs to be reloaded, click OK to reload');
-            if (ok_to_reload) window.location.reload();
+            reload_site();
             return;
         }
         if (websocket_ready) {
